@@ -1,9 +1,9 @@
 BUILD_BIT = '64bit'
 BUILD_CPU = 'ARMv8 (64-bit) Family 8 Model D4C Revision   0, Qualcomm Technologies Inc'
-BUILD_DATE = '2024-11-06'
+BUILD_DATE = '2024-11-11'
 BUILD_MACHINE = 'ARM64'
 BUILD_OS = 'Microsoft Windows 11 Pro'
-BUILD_TIME = '02:08'
+BUILD_TIME = '08:20'
 BUILD_TYPE = ''
 COMPILER_VERSION = 'clang version 18.1.8'
 CYTHON_VERSION = '3.0.11'
@@ -21,7 +21,7 @@ lib_bsdtar = '3.7.7-1'
 lib_bzip2 = '1.0.8-4'
 lib_cacertificates = '20240203-2'
 lib_coreutils = '8.32-5'
-lib_curl = '8.10.1-1'
+lib_curl = '8.11.0-1'
 lib_dash = '0.5.12-1'
 lib_db = '6.2.32-5'
 lib_diffstat = '1.66-1'
@@ -38,7 +38,7 @@ lib_gdbm = '1.24-1'
 lib_getent = '2.18.90-4'
 lib_gettext = '0.22.4-1'
 lib_gmp = '6.3.0-1'
-lib_gnupg = '2.4.5-1'
+lib_gnupg = '2.4.6-1'
 lib_grep = '1~3.0-6'
 lib_gzip = '1.13-1'
 lib_heimdallibs = '7.8.0-5'
@@ -49,15 +49,15 @@ lib_libargp = '20110921-4'
 lib_libasprintf = '0.22.4-1'
 lib_libassuan = '2.5.7-1'
 lib_libbz2 = '1.0.8-4'
-lib_libcurl = '8.10.1-1'
+lib_libcurl = '8.11.0-1'
 lib_libdb = '6.2.32-5'
 lib_libedit = '20240517_3.1-1'
-lib_libexpat = '2.6.3-1'
+lib_libexpat = '2.6.4-1'
 lib_libffi = '3.4.6-1'
 lib_libgcrypt = '1.11.0-1'
 lib_libgdbm = '1.24-1'
 lib_libgettextpo = '0.22.4-1'
-lib_libgnutls = '3.8.7-1'
+lib_libgnutls = '3.8.8-1'
 lib_libgpgerror = '1.50-1'
 lib_libhogweed = '3.10-1'
 lib_libiconv = '1.17-1'
@@ -90,15 +90,15 @@ lib_mingww64clangaarch64atk = '2.54.0-1'
 lib_mingww64clangaarch64brotli = '1.1.0-3'
 lib_mingww64clangaarch64bzip2 = '1.0.8-3'
 lib_mingww64clangaarch64cairo = '1.18.2-1'
-lib_mingww64clangaarch64clang = '18.1.8-1'
-lib_mingww64clangaarch64clanganalyzer = '18.1.8-1'
-lib_mingww64clangaarch64clanglibs = '18.1.8-1'
-lib_mingww64clangaarch64clangtoolsextra = '18.1.8-1'
-lib_mingww64clangaarch64compilerrt = '18.1.8-1'
+lib_mingww64clangaarch64clang = '18.1.8-2'
+lib_mingww64clangaarch64clanganalyzer = '18.1.8-2'
+lib_mingww64clangaarch64clanglibs = '18.1.8-2'
+lib_mingww64clangaarch64clangtoolsextra = '18.1.8-2'
+lib_mingww64clangaarch64compilerrt = '18.1.8-2'
 lib_mingww64clangaarch64crtgit = '12.0.0.r369.g0d4221712-2'
 lib_mingww64clangaarch64cython = '3.0.11-2'
 lib_mingww64clangaarch64eglheaders = '1.5.r255.9ab6036-1'
-lib_mingww64clangaarch64expat = '2.6.3-1'
+lib_mingww64clangaarch64expat = '2.6.4-1'
 lib_mingww64clangaarch64fontconfig = '2.15.0-2'
 lib_mingww64clangaarch64freetype = '2.13.3-1'
 lib_mingww64clangaarch64fribidi = '1.0.16-1'
@@ -111,7 +111,7 @@ lib_mingww64clangaarch64gobjectintrospectionruntime = '1.82.0-2'
 lib_mingww64clangaarch64graphite2 = '1.3.14-3'
 lib_mingww64clangaarch64gtk3 = '3.24.43-1'
 lib_mingww64clangaarch64gtkupdateiconcache = '3.24.43-1'
-lib_mingww64clangaarch64harfbuzz = '10.0.1-1'
+lib_mingww64clangaarch64harfbuzz = '10.1.0-1'
 lib_mingww64clangaarch64headersgit = '12.0.0.r369.g0d4221712-2'
 lib_mingww64clangaarch64hicoloricontheme = '0.18-1'
 lib_mingww64clangaarch64jbigkit = '2.1-5'
@@ -142,10 +142,10 @@ lib_mingww64clangaarch64libwinpthreadgit = '12.0.0.r369.g0d4221712-1'
 lib_mingww64clangaarch64libx264 = '0.164.r3161.a354f11-3'
 lib_mingww64clangaarch64libxml2 = '2.12.9-2'
 lib_mingww64clangaarch64libyuv = '1887.r2537.a6a2ec65-1'
-lib_mingww64clangaarch64lld = '18.1.8-1'
-lib_mingww64clangaarch64lldb = '18.1.8-2'
-lib_mingww64clangaarch64llvm = '18.1.8-1'
-lib_mingww64clangaarch64llvmlibs = '18.1.8-1'
+lib_mingww64clangaarch64lld = '18.1.8-2'
+lib_mingww64clangaarch64lldb = '18.1.8-3'
+lib_mingww64clangaarch64llvm = '18.1.8-2'
+lib_mingww64clangaarch64llvmlibs = '18.1.8-2'
 lib_mingww64clangaarch64llvmopenmp = '18.1.8-1'
 lib_mingww64clangaarch64lua = '5.4.7-2'
 lib_mingww64clangaarch64lz4 = '1.10.0-1'
@@ -157,7 +157,7 @@ lib_mingww64clangaarch64openjpeg2 = '2.5.2-1'
 lib_mingww64clangaarch64openssl = '3.4.0-1'
 lib_mingww64clangaarch64pango = '1.54.0-1'
 lib_mingww64clangaarch64pcre2 = '10.44-1'
-lib_mingww64clangaarch64pixman = '0.43.4-1'
+lib_mingww64clangaarch64pixman = '0.44.0-1'
 lib_mingww64clangaarch64pkgconf = '1~2.3.0-1'
 lib_mingww64clangaarch64python = '3.12.7-2'
 lib_mingww64clangaarch64pythonbuild = '1.2.2-2'
@@ -165,13 +165,15 @@ lib_mingww64clangaarch64pythoncairo = '1.27.0-2'
 lib_mingww64clangaarch64pythoncomtypes = '1.4.8-2'
 lib_mingww64clangaarch64pythongobject = '3.50.0-2'
 lib_mingww64clangaarch64pythoninstaller = '0.7.0-4'
-lib_mingww64clangaarch64pythonpackaging = '24.1-3'
+lib_mingww64clangaarch64pythonpackaging = '24.2-1'
 lib_mingww64clangaarch64pythonpillow = '11.0.0-2'
 lib_mingww64clangaarch64pythonpyopengl = '3.1.7-4'
 lib_mingww64clangaarch64pythonpyprojecthooks = '1.1.0-2'
+lib_mingww64clangaarch64pythonpyvda = '0.4.3-1'
+lib_mingww64clangaarch64pythonpywin32 = '308-3'
 lib_mingww64clangaarch64pythonsetproctitle = '1.3.3-2'
-lib_mingww64clangaarch64pythonsetuptools = '75.1.0-4'
-lib_mingww64clangaarch64pythonsix = '1.16.0-4'
+lib_mingww64clangaarch64pythonsetuptools = '75.3.0-1'
+lib_mingww64clangaarch64pythonsix = '1.16.0-6'
 lib_mingww64clangaarch64readline = '8.2.013-1'
 lib_mingww64clangaarch64sharedmimeinfo = '2.4-1'
 lib_mingww64clangaarch64sqlite3 = '3.46.1-1'
@@ -184,7 +186,7 @@ lib_mingww64clangaarch64wineditline = '2.208-1'
 lib_mingww64clangaarch64winpthreadsgit = '12.0.0.r369.g0d4221712-1'
 lib_mingww64clangaarch64winstorecompatgit = '12.0.0.r369.g0d4221712-1'
 lib_mingww64clangaarch64xxhash = '0.8.2-2'
-lib_mingww64clangaarch64xz = '5.6.3-1'
+lib_mingww64clangaarch64xz = '5.6.3-2'
 lib_mingww64clangaarch64zlib = '1.3.1-1'
 lib_mingww64clangaarch64zstd = '1.5.6-2'
 lib_mintty = '1~3.7.6-1'
